@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Number::Tolerant;
+package Number::Tolerant 1.709;
 # ABSTRACT: tolerance ranges for inexact numbers
-$Number::Tolerant::VERSION = '1.708';
+
 use Sub::Exporter::Util;
 use Sub::Exporter 0.950 -setup => {
   exports => { tolerance => Sub::Exporter::Util::curry_class('new'), },
@@ -530,7 +530,7 @@ Number::Tolerant - tolerance ranges for inexact numbers
 
 =head1 VERSION
 
-version 1.708
+version 1.709
 
 =head1 SYNOPSIS
 
@@ -554,6 +554,16 @@ specified tolerances.
 
  reject $product unless $measurement == $specification;
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 Instantiation
@@ -798,7 +808,7 @@ also provided the initial implementation for the offset type.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
