@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Number::Tolerant::Type;
+package Number::Tolerant::Type 1.709;
 # ABSTRACT: a type of tolerance
-$Number::Tolerant::Type::VERSION = '1.708';
+
 use parent qw(Number::Tolerant);
 use Math::BigFloat;
 use Math::BigRat;
@@ -122,10 +122,20 @@ Number::Tolerant::Type - a type of tolerance
 
 =head1 VERSION
 
-version 1.708
+version 1.709
 
 =head1 SYNOPSIS
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 valid_args
@@ -180,7 +190,7 @@ When parsing "4 <= x <= 10" this regular expression is used to match the letter
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
