@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Test::Tolerant;
+package Test::Tolerant 1.709;
 # ABSTRACT: test routines for testing numbers against tolerances
-$Test::Tolerant::VERSION = '1.708';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod   use Test::More;
@@ -98,7 +98,7 @@ Test::Tolerant - test routines for testing numbers against tolerances
 
 =head1 VERSION
 
-version 1.708
+version 1.709
 
 =head1 SYNOPSIS
 
@@ -110,6 +110,16 @@ version 1.708
 
   done_testing;
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 FUNCTIONS
 
 =head2 is_tol
@@ -138,7 +148,7 @@ this:
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
